@@ -185,3 +185,27 @@ def ascii_binary_to_vhdl_code(ascii_binary):
         i += 1
     print "    " + str(i + 1) + "  => \"0000000000000000\""
     print ");"
+
+def ascii_binary_to_c_code(ascii_binary):
+    number_of_instructions = len(ascii_binary)/32
+    low = []
+    high = []
+
+    for _ in xrange(number_of_instructions):
+        high_n = ascii_binary[:16]
+        low_n = ascii_binary[16:32]
+        ascii_binary = ascii_binary[32:]
+        low.append(hex(int(low_n, 2)))
+        high.append(hex(int(high_n, 2)))
+
+    print "fpga_set_state(&cpu_bus, INSTRUCTION_LOW_ACCESS);"
+
+    for i in xrange(number_of_instructions):
+        print "set_cpu_memory(&cpu_bus, %s, %s);" % (hex(i), low[i])
+
+    print "fpga_set_state(&cpu_bus, INSTRUCTION_HIGH_ACCESS);"
+
+    for i in xrange(number_of_instructions):
+        print "set_cpu_memory(&cpu_bus, %s, %s);" % (hex(i), high[i])
+
+    print "fpga_set_state(&cpu_bus, RUN);"
