@@ -47,9 +47,9 @@ scanner = re.Scanner([
     (r'\b(add|addi|and|andi|call|call|jmp|ld|ldi|ret|' +
      r'ldg|mul|muli|or|ori|setg|sll|slli|sra|srai|srl|' +
      r'srli|st|sti|stg|sub|subi|xor|xori|cmp|mv|neg|nop|not)\b', s_operator),
-    ('(equal|not equal|greater than|greater than or equal|less than|' +
-     r'less than or equal|zero|not zero|positive|positive or zero|' +
-     r'negative|negative or zero|overflow|not overflow|never|always)',
+    (r'(less that or equal|greater than or equal|not equal|greater than|' +
+     r'equal|less than|not zero|zero|positive or zero|positive|' +
+     r'negative or zero|negative|not overflow|overflow|never|always)',
      s_condition),
     ('[^ :0-9\n\t\v][^ :\n\t\v]*', s_label),
 ])
